@@ -1,4 +1,4 @@
-#' Print the Summary of an \code{lqmix} object
+#' Print the summary of an \code{lqmix} object
 #'
 #' Print the summary of an object of \code{\link{class}} \code{lqmix}
 #'
@@ -52,6 +52,7 @@ print.summary.lqmix = function(x, digits = max (3, getOption("digits") -3), ...)
   }
 
   if(!is.null(x$ranTC) & !is.null(x$ranTV)){ #TCTV
+
     cat("\nTime-Constant Random Coefficients:\n")
     printCoefmat(round(x$ranTC, digits), P.values=TRUE, has.Pvalue=TRUE,
                  signif.stars = TRUE, signif.legend = F)
@@ -110,7 +111,7 @@ print.summary.lqmix = function(x, digits = max (3, getOption("digits") -3), ...)
   }
 
   cat("\nLog-likelihood at convergence:", round(x$lk, digits))
-  cat("\nNumber of observations:", x$nobs, "- Number of subjects:", x$nsbjs)
+  cat("\nNumber of observations:", x$nobs, "- Number of subjects:", x$nsbjs, "\n")
 
   if(x$miss == "non-monotone" & x$mod != "TC") message("Data affected by non-monotone missingness: parameter estimates may be biased.")
 
